#include <iostream>
#include <cstdlib>
#include <cmath>
 
using namespace std;
 
typedef unsigned long long ULL;
 
ULL wit[] = {2, 3, 5, 7, 11, 13, 17, 19, 0};
ULL mask = 0xffff;
 
ULL mul(ULL a, ULL b, ULL m) {
  ULL p = 0;
  for (; b; b>>=1, a = (a<<1)%m)
    if (b&1)
      p = (p+a)%m;
  return p;
}
 
ULL fast_exp(ULL a, ULL b, ULL m) {
  ULL x = 1;
  while (b) {
    if (b&1) x = mul(x,a,m);
    a = mul(a,a,m);
    b >>= 1;
  }
  return x;
}
 
bool rabin_miller(ULL a, ULL n, ULL s, ULL d) {
  ULL x = fast_exp(a%n,d,n);
  if (x == 1 || x == n-1) return false;
  while (--s) {
    x = mul(x,x,n);
    if (x == 1) return true;
    if (x == n-1) return false;
  }
  return true;
}
 
ULL isprime(ULL n) {
  ULL d = n-1, s = 0;
  while (!(d&1)) {
    d >>= 1;
    ++s;
  }
 
  for (int i = 0; wit[i]; ++i) {
    if (wit[i] == n) return true;
    else if (n%wit[i] == 0 || rabin_miller(wit[i], n, s, d)) return false;
  }
  return true;
}
 
const int NUMP = 1100000;
 
ULL pl[NUMP];
int np;
 
ULL solve(ULL n) {
  if (n == 4) return 1;
 
  ULL vp = 0;
  for (int i = 0; pl[i]*pl[i]*pl[i] <= n; ++i)
    if (n%pl[i] == 0) {
      if (n%(pl[i]*pl[i]) == 0) return 0;
      ++vp;
      n /= pl[i];
    }
 
  if (n > 1) {
    ULL r = ULL(sqrt(double(n)));
 
    while (r*r <= n) ++r;
    while (r*r > n) --r;
    if (r*r == n) return 0;
 
    if (isprime(n)) ++vp;
    else vp += 2;
  }
 
  ULL f = 1;
  for (ULL i = 2; i <= vp; ++i) f *= i;
  return f;
}
 
int main() {
 
  for (int i = 0; i < NUMP; ++i) pl[i] = i;
  for (ULL i = 2; i < NUMP; ++i)
    if (pl[i] == i) {
      pl[np++] = i;
      for (ULL j = i*i; j < NUMP; j += i)
	pl[j] = i;
    }
 
  int t;
  cin >> t;
  while (t--) {
    ULL n, k;
    cin >> n;
    k = solve(n);
    if (k == 0) cout << -1 << endl;
    else cout << k << endl;
  }
}
 